Change WarnUnsupported to ErrorUnsupported (in name and in practice).
 - We are beyond the point where this shows up often and when it does
   generating miscompiled files is bad.


git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@54836 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/CodeGenModule.h b/lib/CodeGen/CodeGenModule.h
index 5f3714c..8188251 100644
--- a/lib/CodeGen/CodeGenModule.h
+++ b/lib/CodeGen/CodeGenModule.h
@@ -188,13 +188,13 @@
   llvm::Constant *EmitAnnotateAttr(llvm::GlobalValue *GV,
                                    const AnnotateAttr *AA, unsigned LineNo);
     
   /// WarnUnsupported - Print out a warning that codegen doesn't support the
   /// specified stmt yet.    
-  void WarnUnsupported(const Stmt *S, const char *Type);
+  void ErrorUnsupported(const Stmt *S, const char *Type);
   
   /// WarnUnsupported - Print out a warning that codegen doesn't support the
   /// specified decl yet.
-  void WarnUnsupported(const Decl *D, const char *Type);
+  void ErrorUnsupported(const Decl *D, const char *Type);
 
 private:
   void SetFunctionAttributes(const FunctionDecl *FD,
@@ -188,13 +188,13 @@
                                    const AnnotateAttr *AA, unsigned LineNo);
     
-  /// WarnUnsupported - Print out a warning that codegen doesn't support the
+  /// ErrorUnsupported - Print out an error that codegen doesn't support the
   /// specified stmt yet.    
@@ -188,13 +188,13 @@
   
-  /// WarnUnsupported - Print out a warning that codegen doesn't support the
+  /// ErrorUnsupported - Print out an error that codegen doesn't support the
   /// specified decl yet.